| mispitools-deprecated | R Documentation |
These functions are deprecated and will be removed in a future version of mispitools. Please use the new function names instead.
The function names have been updated to follow a consistent snake_case naming convention with semantic prefixes:
sim_*: Simulation functions
lr_*: Likelihood ratio functions
plot_*: Visualization functions
cpt_*: Conditional probability table functions
kl_*: Kullback-Leibler divergence functions
simLRgen(...)
simLRprelim(...)
simLR2dataframe(...)
simRef(...)
makePOIprelim(...)
makeMPprelim(...)
LRsex(...)
LRage(...)
LRcol(...)
LRcolors(...)
LRdate(...)
combLR(...)
compute_LRs_colors(...)
CPT_POP(...)
CPT_MP(...)
Cmodel(...)
LRdist(...)
deplot(...)
CondPlot(...)
DeT(...)
Trates(...)
getfreqs(...)
conditionedProp(...)
refProp(...)
mispiApp(...)
lrComparisonApp(...)
app_mispitools(...)
app_lr_comparison(...)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.