View source: R/lr_hair_color.R
| lr_hair_color | R Documentation |
Simulates hair color observations and optionally computes likelihood ratios (LRs) under either H1 (unidentified person is the missing person) or H2 (unidentified person is not the missing person).
Hair color is categorized into 5 groups: 1=Black, 2=Brown, 3=Blonde, 4=Red, 5=Gray/White
lr_hair_color(
MPc = 1,
epc = error_matrix_hair(),
erRc = epc,
numsims = 1000,
Pc = c(0.3, 0.2, 0.25, 0.15, 0.1),
H = 1,
Qprop = MPc,
LR = FALSE,
seed = 1234,
nsims = NULL
)
MPc |
Integer (1-5). Missing person's hair color category. Default: 1. |
epc |
Matrix. Hair color error/confusion matrix, typically created
with |
erRc |
Matrix. Error matrix for the reference/database.
Defaults to |
numsims |
Integer. Number of simulations to perform. Default: 1000. |
Pc |
Numeric vector of length 5. Hair color proportions in the population. Must sum to 1. Default: c(0.3, 0.2, 0.25, 0.15, 0.1). |
H |
Integer (1 or 2). Hypothesis to simulate under:
Default: 1. |
Qprop |
Integer. Query color for testing. Defaults to |
LR |
Logical. If TRUE, compute and return LR values. Default: FALSE. |
seed |
Integer. Random seed for reproducibility. Default: 1234. |
nsims |
Deprecated. Use |
Under H1 (Related): Observed color is sampled using the row of the error matrix corresponding to the MP's true hair color. This accounts for observation errors.
Under H2 (Unrelated): Color is sampled from the population proportions Pc.
LR Calculation:
LR = P(observed color | true color is MPc) / P(observed color in population)
LR = epc(MPc, observed) / Pc(observed)
A data.frame with column Col containing simulated color
observations (1-5). If LR = TRUE, also includes column LRc
with the likelihood ratio for each observation.
Soft-deprecated in mispitools 2.0. This feature is generalised by
nongenetic_feature (a categorical feature with a full
confusion matrix); the unified per-feature engine reproduces
epc[MPc, o] / Pc[o] exactly. The legacy function still works
for the 2.0 release-candidate cycle and will be removed afterwards.
Marsico FL, et al. (2023). "Likelihood ratios for non-genetic evidence in missing person cases." Forensic Science International: Genetics, 66, 102891. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.fsigen.2023.102891")}
nongenetic_feature for the unified replacement,
error_matrix_hair for creating the error matrix,
lr_pigmentation for combined pigmentation traits,
sim_lr_prelim for unified preliminary LR simulations.
# Simulate under H1 (related) with black hair MP
sim_h1 <- lr_hair_color(MPc = 1, H = 1, numsims = 100)
table(sim_h1$Col)
# Simulate under H2 with LR values
sim_h2 <- lr_hair_color(MPc = 2, H = 2, numsims = 100, LR = TRUE)
head(sim_h2)
summary(sim_h2$LRc)
# Custom population proportions
sim_custom <- lr_hair_color(
MPc = 3, # Blonde
Pc = c(0.1, 0.4, 0.3, 0.1, 0.1), # Different population
numsims = 500,
LR = TRUE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.